/*
 * termcap.c
 *
 * This file is a intended to be inherited by objects wishing
 * to do full-screen movements.
 *
 * Copyright (c) 1993 Peter Eriksson <pen@lysator.liu.se>
 *
 * Everyone is granted permission to copy and modify this file
 * under the condition that this copyright notice remains unchanged.
 */
#pragma strict_types

#define _IN_TERMCAP_C_

#include <termcap.h>


static object tob;
static int tflags;
static string writebuf;


void reset(int arg) {
    if (!arg)  {
	tflags = 0;
	writebuf = "";
    }
}



int tputs(mixed str) {
    if (!str || !stringp(str))
	return 0;
    
    if (tflags & F_BUFFERED) {
	if (!writebuf)
	    writebuf = "";

	writebuf += str;

	return 0;
    }
    else {
	write(str);
	return 1;
    }
}


int tinit(mixed fterm) {
    string term;
    
    if (!fterm || !stringp(fterm)) {
	if (!this_player())
	    return -1;
	
	term = (string) this_player()->query_term();
    }
    else
	term = fterm;
    
    if (!term)
	term = "unknown";

    tob = clone_object("obj/termlib/"+term);
    if (!tob)
	return -1;

    return tputs((string) tob->tinit());
}


int texit() {
    return tputs((string) tob->texit());
}


int tgoto(int x, int y) {
    string str;
    
    str = (string) tob->tgoto(x, y);
    if (!str)
	return -1;
    else
	return tputs(str);
}


int tclear() {
    string str;
    
    str = (string) tob->tclear();
    if (!str)
	return -1;
    else
	return tputs(str);
}


int tclreol() {
    string str;
    
    str = (string) tob->clreol();
    if (!str)
	return -1;
    else
	return tputs(str);
}


int tbold(int onoff) {
    string str;
    
    str = (string) tob->tbold(onoff);
    if (!str)
	return -1;
    else
	return tputs(str);
}



int tflush() {
    if (writebuf && stringp(writebuf))
	write(writebuf);

    writebuf = "";
}


mixed tioctl(int opt, mixed arg) {
    switch (opt) {
	case T_SETFL:
	    tflags = arg;
	    break;

	case T_GETFL:
	    return tflags;

	default:
	    return -1;
    }
}
